ovhcloud_cloud_managed-kubernetes_oidc_create.md

May 7, 2026 ยท View on GitHub

ovhcloud cloud managed-kubernetes oidc create

Create a new OIDC integration for the given Kubernetes cluster

Synopsis

Use this command to create a new OIDC integration for the given Kubernetes cluster. There are three ways to define the parameters:

  1. Using only CLI flags:

    ovhcloud cloud managed-kubernetes oidc create <cluster_id> --issuer-url

  2. Using a configuration file:

First you can generate an example of parameters file using the following command:

ovhcloud cloud managed-kubernetes oidc create <cluster_id> --init-file ./params.json

You will be able to choose from several examples of parameters. Once an example has been selected, the content is written in the given file. After editing the file to set the correct creation parameters, run:

ovhcloud cloud managed-kubernetes oidc create <cluster_id> --from-file ./params.json

Note that you can also pipe the content of the parameters file, like the following:

cat ./params.json | ovhcloud cloud managed-kubernetes oidc create <cluster_id>

In both cases, you can override the parameters in the given file using command line flags, for example:

ovhcloud cloud managed-kubernetes oidc create <cluster_id> --from-file ./params.json --client-id <client_id>

3. Using your default text editor:

ovhcloud cloud managed-kubernetes oidc create <cluster_id> --editor

You will be able to choose from several examples of parameters. Once an example has been selected, the CLI will open your default text editor to update the parameters. When saving the file, the creation will start.

Note that it is also possible to override values in the presented examples using command line flags like the following:

ovhcloud cloud managed-kubernetes oidc create <cluster_id> --editor --client-id <client_id>
ovhcloud cloud managed-kubernetes oidc create <cluster_id> [flags]

Options

      --ca-content string            CA certificate content for the OIDC provider
      --client-id string             OIDC client ID
      --editor                       Use a text editor to define parameters
      --from-file string             File containing parameters
      --groups-claim strings         OIDC groups claim(s)
      --groups-prefix string         Prefix prepended to group claims
  -h, --help                         help for create
      --init-file string             Create a file with example parameters
      --issuer-url string            OIDC issuer URL
      --replace                      Replace parameters file if it already exists
      --required-claim strings       OIDC required claim(s)
      --signing-algorithms strings   OIDC signing algorithm(s) (ES256, ES384, ES512, PS256, PS384, PS512, RS256, RS384, RS512)
      --username-claim string        OIDC username claim
      --username-prefix string       Prefix prepended to username claims

Options inherited from parent commands

      --cloud-project string   Cloud project ID
  -d, --debug                  Activate debug mode (will log all HTTP requests details)
  -e, --ignore-errors          Ignore errors in API calls when it is not fatal to the execution
  -o, --output string          Output format: json, yaml, interactive, or a custom format expression (using https://github.com/PaesslerAG/gval syntax)
                               Examples:
                                 --output json
                                 --output yaml
                                 --output interactive
                                 --output 'id' (to extract a single field)
                                 --output 'nested.field.subfield' (to extract a nested field)
                                 --output '[id, "name"]' (to extract multiple fields as an array)
                                 --output '{"newKey": oldKey, "otherKey": nested.field}' (to extract and rename fields in an object)
                                 --output 'name+","+type' (to extract and concatenate fields in a string)
                                 --output '(nbFieldA + nbFieldB) * 10' (to compute values from numeric fields)
      --profile string         Use a specific profile from the configuration file

SEE ALSO